@@ -193,11 +193,9 @@ class Apply(Node, Generic[OpType]):
             if len(self.outputs) == 1:
                 return self.outputs[0]
             else:
-                raise ValueError(f"{self.op}.default_output should be an output index.")
-        elif not isinstance(do, int):
-            raise ValueError(f"{self.op}.default_output should be an int or long")
-        elif do < 0 or do >= len(self.outputs):
-            raise ValueError(f"{self.op}.default_output is out of range.")
+                raise ValueError(
+                    f"Multi-output Op {self.op} default_output not specified"
+                )
         return self.outputs[do]
 
     def __str__(self):
@@ -597,6 +595,22 @@ class Variable(Node, Generic[_TypeType, OptionalApplyType]):
         if inputs_to_values is None:
             inputs_to_values = {}
 
+        def convert_string_keys_to_variables(input_to_values):
+            new_input_to_values = {}
+            for key, value in inputs_to_values.items():
+                if isinstance(key, str):
+                    matching_vars = get_var_by_name([self], key)
+                    if not matching_vars:
+                        raise Exception(f"{key} not found in graph")
+                    elif len(matching_vars) > 1:
+                        raise Exception(f"Found multiple variables with name {key}")
+                    new_input_to_values[matching_vars[0]] = value
+                else:
+                    new_input_to_values[key] = value
+            return new_input_to_values
+
+        inputs_to_values = convert_string_keys_to_variables(inputs_to_values)
+
         if not hasattr(self, "_fn_cache"):
             self._fn_cache = dict()
 
