@@ -7,6 +7,7 @@ from typing import (
     Dict,
     Iterable,
     List,
+    Literal,
     Optional,
     Sequence,
     Set,
@@ -15,8 +16,6 @@ from typing import (
     cast,
 )
 
-from typing_extensions import Literal
-
 import pytensor
 from pytensor.configdefaults import config
 from pytensor.graph.basic import Apply, AtomicVariable, Variable, applys_between
@@ -545,7 +544,7 @@ class FunctionGraph(MetaObject):
         self.outputs.pop(idx)
 
         new_idx = 0
-        for (out, old_idx) in old_idx_mappings:
+        for out, old_idx in old_idx_mappings:
             if old_idx == idx:
                 continue
             out_clients = self.clients[out]
@@ -580,7 +579,6 @@ class FunctionGraph(MetaObject):
                 out_client, out_idx = out_clients.pop()
 
                 if out_client == "output":
-
                     self._remove_output(out_idx)
 
                     # TODO: We could short-circuit all of the graph walking and
@@ -606,7 +604,6 @@ class FunctionGraph(MetaObject):
         # Remove all the arrows pointing to this `node`, and any orphaned
         # variables created by removing those arrows
         for inp_idx, inp in enumerate(node.inputs):
-
             inp_clients: List[ClientType] = self.clients.get(inp, [])
 
             arrow = (node, inp_idx)
