@@ -9,6 +9,7 @@ from typing import (
     Dict,
     List,
     Optional,
+    Protocol,
     Sequence,
     Tuple,
     TypeVar,
@@ -16,8 +17,6 @@ from typing import (
     cast,
 )
 
-from typing_extensions import Protocol
-
 import pytensor
 from pytensor.configdefaults import config
 from pytensor.graph.basic import Apply, NoParams, Variable
