@@ -1,6 +1,9 @@
 import pytensor.tensor.rewriting.basic
 import pytensor.tensor.rewriting.elemwise
 import pytensor.tensor.rewriting.extra_ops
+
+# Register JAX specializations
+import pytensor.tensor.rewriting.jax
 import pytensor.tensor.rewriting.math
 import pytensor.tensor.rewriting.shape
 import pytensor.tensor.rewriting.special
