@@ -756,8 +756,8 @@ class _tensor_py_operators:
     # This value is set so that PyTensor arrays will trump NumPy operators.
     __array_priority__ = 1000
 
-    def get_scalar_constant_value(self):
-        return at.basic.get_scalar_constant_value(self)
+    def get_underlying_scalar_constant(self):
+        return at.basic.get_underlying_scalar_constant_value(self)
 
     def zeros_like(model, dtype=None):
         return at.basic.zeros_like(model, dtype=dtype)
